@@ -69,6 +69,10 @@ class _GISType(UserDefinedType):
 
         The dimension of the geometry. Default is ``2``.
 
+        When set to ``3`` then the "geometry_type" is constrained to terminate
+        on either ``"Z"`` or ``"M"``. When set to ``4`` then the
+        "geometry_type" must terminate with ``"ZM"``.
+
     ``spatial_index``
 
         Indicate if a spatial index should be created. Default is ``True``.
@@ -89,14 +93,6 @@ class _GISType(UserDefinedType):
         ``AddGeometryColumn``. Note that this option is only taken
         into account if ``management`` is set to ``True`` and is only available
         for PostGIS 2.x.
-
-    ``use_st_prefix``
-
-        Whether to use the ``ST_`` versions of the from_text and as_binary
-        functions. For example, for Geometry, ``GeomFromEWKT`` will be used
-        if ``use_st_prefix`` is ``False``, otherwise ``ST_GeomFromEWKT`` will
-        be used. Default is ``True``.
-
     """
 
     name = None
@@ -116,20 +112,16 @@ class _GISType(UserDefinedType):
         geometry/geography columns. """
 
     def __init__(self, geometry_type='GEOMETRY', srid=-1, dimension=2,
-                 spatial_index=True, management=False, use_typmod=None, use_st_prefix=True):
+                 spatial_index=True, management=False, use_typmod=None):
         geometry_type, srid = self.check_ctor_args(
-            geometry_type, srid, management, use_typmod)
+            geometry_type, srid, dimension, management, use_typmod)
         self.geometry_type = geometry_type
         self.srid = srid
         self.dimension = dimension
         self.spatial_index = spatial_index
         self.management = management
         self.use_typmod = use_typmod
-        self.extended = self.as_binary == 'AsEWKB'
-        self.use_st_prefix = use_st_prefix
-        if use_st_prefix:
-            self.from_text = 'ST_' + self.from_text
-            self.as_binary = 'ST_' + self.as_binary
+        self.extended = self.as_binary == 'ST_AsEWKB'
 
     def get_col_spec(self):
         if not self.geometry_type:
@@ -142,8 +134,7 @@ class _GISType(UserDefinedType):
     def result_processor(self, dialect, coltype):
         def process(value):
             if value is not None:
-                return WKBElement(value, srid=self.srid, extended=self.extended,
-                                  use_st_prefix=self.use_st_prefix)
+                return WKBElement(value, srid=self.srid, extended=self.extended)
         return process
 
     def bind_expression(self, bindvalue):
@@ -152,25 +143,45 @@ class _GISType(UserDefinedType):
     def bind_processor(self, dialect):
         def process(bindvalue):
             if isinstance(bindvalue, WKTElement):
-                return 'SRID=%d;%s' % (bindvalue.srid, bindvalue.data)
+                if bindvalue.extended:
+                    return '%s' % (bindvalue.data)
+                else:
+                    return 'SRID=%d;%s' % (bindvalue.srid, bindvalue.data)
             else:
                 return bindvalue
         return process
 
     @staticmethod
-    def check_ctor_args(geometry_type, srid, management, use_typmod):
+    def check_ctor_args(geometry_type, srid, dimension, management, use_typmod):
         try:
             srid = int(srid)
         except ValueError:
             raise ArgumentError('srid must be convertible to an integer')
         if geometry_type:
             geometry_type = geometry_type.upper()
+
+            if ((dimension == 4 and not geometry_type.endswith('ZM'))
+                or (dimension == 3
+                    and not (geometry_type.endswith('Z')
+                             or (geometry_type.endswith('M')
+                             and not geometry_type.endswith('ZM'))))
+                or (dimension == 2
+                    and (geometry_type.endswith('ZM')
+                         or geometry_type.endswith('Z')
+                         or geometry_type.endswith('M')))):
+                raise ArgumentError(
+                    'invalid geometry_type {!r} for dimension {}'.format(
+                        geometry_type, dimension))
         else:
             if management:
                 raise ArgumentError('geometry_type set to None not compatible '
                                     'with management')
             if srid > 0:
                 warnings.warn('srid not enforced when geometry_type is None')
+
+            if dimension > 2:
+                raise ArgumentError('geometry type set to None not compatible '
+                                    'with dimension > 2')
         if use_typmod and not management:
             warnings.warn('use_typmod ignored when management is False')
         return geometry_type, srid
@@ -187,16 +198,21 @@ class Geometry(_GISType):
     See :class:`geoalchemy2.types._GISType` for the list of arguments that can
     be passed to the constructor.
 
+    If ``srid`` is set then the ``WKBElement` objects resulting from queries will
+    have that SRID, and, when constructing the ``WKBElement`` objects, the SRID
+    won't be read from the data returned by the database. If ``srid`` is not set
+    (meaning it's ``-1``) then the SRID set in ``WKBElement` objects will be read
+    from the data returned by the database.
     """
 
     name = 'geometry'
     """ Type name used for defining geometry columns in ``CREATE TABLE``. """
 
-    from_text = 'GeomFromEWKT'
+    from_text = 'ST_GeomFromEWKT'
     """ The "from text" geometry constructor. Used by the parent class'
         ``bind_expression`` method. """
 
-    as_binary = 'AsEWKB'
+    as_binary = 'ST_AsEWKB'
     """ The "as binary" function to use. Used by the parent class'
         ``column_expression`` method. """
 
@@ -217,11 +233,11 @@ class Geography(_GISType):
     name = 'geography'
     """ Type name used for defining geography columns in ``CREATE TABLE``. """
 
-    from_text = 'GeogFromText'
+    from_text = 'ST_GeogFromText'
     """ The ``FromText`` geography constructor. Used by the parent class'
         ``bind_expression`` method. """
 
-    as_binary = 'AsBinary'
+    as_binary = 'ST_AsBinary'
     """ The "as binary" function to use. Used by the parent class'
         ``column_expression`` method. """
 
